@use "sass:color";

$scheme-name: "sunrise";
$base-color: #cf4944;
$highlight-color: #dd823b;
$notification-color: #ccaf0b;
$menu-submenu-focus-text: color.adjust($highlight-color, $lightness: 35%);

@import "../_admin.scss";
